@@ -2,6 +2,7 @@ import sys
 from PyQt4 import QtGui, QtCore
 from dialogs import LoginDialog
 from main import PydoshWindow
+import stylesheet
 QtCore.pyqtRemoveInputHook()
 import pydosh_rc
 
@@ -17,11 +18,14 @@ def main():
 	QtCore.QCoreApplication.setOrganizationName("innerhippy")
 	QtCore.QCoreApplication.setOrganizationDomain("innerhippy.com")
 
+	stylesheet.setStylesheet()
+
 	loginDialog = LoginDialog()
 	loginDialog.show()
 	loginDialog.raise_()
 
 	if loginDialog.exec_():
+		
 		window = PydoshWindow()
 		window.show()
 		return app.exec_()
